@@ -154,7 +154,7 @@
 (Hairline\ Quadrata Hairline\ Quadrata Light Condensed Pen Gothic Handwritten Medieval)
 (Hand\ Drawn\ Shapes Hand\ Drawn\ Shapes Bold SansSerif Distorted)
 (Handserif Handserif Oblique SansSerif Retro)
-(HeadLineA HeadLineA Title)
+(HeadLineA HeadLineA SansSerif Title)
 (Hei Hei SansSerif)
 (Heiti\ SC Heiti\ SC SansSerif)
 (Heiti\ TC Heiti\ TC SansSerif)
@@ -169,7 +169,7 @@
 (Hiragino\ Mincho\ ProN Hiragino\ Mincho\ ProN)
 (Hiragino\ Sans\ GB Hiragino\ GB SansSerif)
 (Hoefler\ Text Hoefler\ Text)
-(Impact Impact Title)
+(Impact Impact SansSerif Title)
 (InaiMathi InaiMathi SansSerif)
 (IPAGothic IPAGothic Bold SansSerif)
 (IPAMincho IPAMincho)
@@ -402,9 +402,6 @@
 (TeX\ Va\ Handwriting va Pen Handwritten)
 (TeXmacs\ Avant\ Garde avant-garde SansSerif)
 (TeXmacs\ Bookman bookman)
-(TeXmacs\ CMU modern)
-(TeXmacs\ CMU\ Mono modern Typewriter)
-(TeXmacs\ CMU\ Sans modern SansSerif)
 (TeXmacs\ Computer\ Modern roman)
 (TeXmacs\ Computer\ Modern\ Mono roman Typewriter)
 (TeXmacs\ Computer\ Modern\ Sans roman SansSerif)
