@@ -32,7 +32,7 @@
 (tm-define (bib-preprocessing t) (:mode bib-plain?) `())
 
 (tm-define (bib-format-name x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (let* ((ff (if (bib-null? (list-ref x 1)) "" `(concat ,(list-ref x 1) (nbsp))))
 	 (vv (if (bib-null? (list-ref x 2)) "" `(concat ,(list-ref x 2) (nbsp))))
 	 (ll (if (bib-null? (list-ref x 3)) "" (bib-purify (list-ref x 3))))
@@ -47,7 +47,7 @@
 	       ,(bib-format-names-rec (+ n 1) lim a))))
 
 (tm-define (bib-format-names a)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (if (or (bib-null? a) (nlist? a))
       ""
       (let* ((n (length a)))
@@ -63,14 +63,14 @@
 	      `(concat ,b ,m ,e))))))
 
 (tm-define (bib-format-author x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (with a (bib-field x "author")
     (if (bib-null? a)
 	""
 	(bib-format-names a))))
 
 (tm-define (bib-format-editor x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (with a (bib-field x "editor")
     (if (or (bib-null? a) (nlist? a))
 	""
@@ -79,7 +79,7 @@
 	    `(concat ,(bib-format-names a) ,(bib-translate ", editors"))))))
 
 (tm-define (bib-format-in-ed-booktitle x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (let* ((b (bib-default-field x "booktitle"))
 	 (e (bib-field x "editor")))
     (if (bib-null? b)
@@ -90,7 +90,7 @@
                      (with "font-shape" "italic" ,b))))))
 
 (tm-define (bib-format-bvolume x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (let* ((v (bib-field x "volume"))
 	 (s (bib-default-field x "series")))
     (if (bib-null? v)
@@ -102,7 +102,7 @@
 	  `(concat ,(bib-translate "volume") ,sep ,v ,series)))))
 
 (tm-define (bib-format-number-series x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (let* ((v (bib-field x "volume"))
 	 (n (bib-field x "number"))
 	 (s (bib-default-field x "series")))
@@ -116,7 +116,7 @@
 	"")))
 
 (tm-define (bib-format-pages x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (with p (bib-field x "pages")
     (cond
       ((or (bib-null? p) (nlist? p)) "")
@@ -128,7 +128,7 @@
 		 ,(list-ref p 1) "--" ,(list-ref p 2))))))
 
 (tm-define (bib-format-chapter-pages x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (let* ((c (bib-field x "chapter"))
 	 (t (bib-field x "type")))
     (if (bib-null? c)
@@ -140,7 +140,7 @@
 	  `(concat ,type " " ,c ,pages)))))
 
 (tm-define (bib-format-vol-num-pages x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (let* ((v (bib-field x "volume"))
 	 (n (bib-field x "number"))
 	 (p (bib-field x "pages"))
@@ -156,7 +156,7 @@
     `(concat ,vol ,num ,pag)))
 
 (tm-define (bib-format-date x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (let* ((y (bib-field x "year"))
 	 (m (bib-field x "month")))
     (if (bib-null? y)
@@ -164,7 +164,7 @@
 	(if (bib-null? m) y `(concat ,m " " ,y)))))
 
 (tm-define (bib-format-tr-number x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (let* ((t (bib-field x "type"))
 	 (n (bib-field x "number"))
 	 (type (if (bib-null? t) (bib-translate "Technical Report") t))
@@ -174,11 +174,11 @@
         `(concat ,type ,sep ,number))))
 
 (tm-define (bib-format-bibitem n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(bibitem* ,(number->string n)))
 
 (tm-define (bib-format-article n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -198,7 +198,7 @@
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-book n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -231,7 +231,7 @@
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-booklet n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -246,7 +246,7 @@
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-inbook n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -276,7 +276,7 @@
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-incollection n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -302,7 +302,7 @@
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-inproceedings n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
     ,(bib-format-bibitem n x)
     (label ,(string-append "bib-" (list-ref x 2)))
@@ -336,7 +336,7 @@
 	,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-manual n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -360,7 +360,7 @@
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-mastersthesis n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -378,7 +378,7 @@
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-misc n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -392,7 +392,7 @@
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-phdthesis n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -410,7 +410,7 @@
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-proceedings n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -442,7 +442,7 @@
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-techreport n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -458,7 +458,7 @@
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
 (tm-define (bib-format-unpublished n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   `(concat
      ,(bib-format-bibitem n x)
      (label ,(string-append "bib-" (list-ref x 2)))
@@ -471,7 +471,7 @@
 	      ,(bib-format-date x))))))))
 
 (tm-define (bib-format-entry n x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (if (and (list? x) (func? x 'bib-entry)
 	   (= (length x) 4) (func? (list-ref x 3) 'document))
       (with doctype (list-ref x 1)
@@ -522,7 +522,7 @@
       (string-upcase (author-sort-format (bib-cdr (bib-field x ae))))))
 
 (tm-define (bib-sort-key x)
-  (:mode bib-plain?)
+  ;; (:mode bib-plain?)
   (let* ((doctype (list-ref x 1))
 	 (pre (cond
 		((or (equal? doctype "inbook") (equal? doctype "book"))
