@@ -1,4 +1,3 @@
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; MODULE      : latex-drd.scm
@@ -52,15 +51,14 @@
   Loop)
 
 (logic-group latex-command-1%
-  part part* chapter chapter*
-  section section* subsection subsection* subsubsection subsubsection*
-  paragraph paragraph* subparagraph subparagraph* nextbib
+  part* chapter* section* subsection* subsubsection* paragraph* subparagraph*
+  nextbib
   footnote overline underline <sub> <sup> not left middle right
   big Big bigg Bigg bigl Bigl biggl Biggl
   bigm Bigm biggm Biggm bigr Bigr biggr Biggr
-  bar hat tilde widehat widetilde vec bm
-  grave acute check breve invbreve abovering mathring
-  dot ddot dddot ddddot mod pod pmod
+  bar Bar hat Hat tilde Tilde widehat widetilde vec Vec bm
+  grave Grave acute Acute check Check breve Breve invbreve abovering mathring
+  dot Dot ddot Ddot dddot ddddot mod pod pmod
   label ref pageref index hspace hspace* vspace vspace*
   mbox hbox textnormal text not substack
   ,(string->symbol "'") ,(string->symbol "`") ,(string->symbol "\"")
@@ -70,7 +68,7 @@
   arabic alph Alph roman Roman fnsymbol displaylines cases underbrace overbrace
   phantom hphantom vphantom smash date terms
   newcounter stepcounter refstepcounter value
-  citet citep citet* citep* citealt citealp citealt* citealp*
+  citealt citealt* citealp*
   citetext citeauthor citeauthor* citeyear onlinecite
   epsfig url penalty centerline fbox framebox cline cmidrule
   enlargethispage
@@ -85,7 +83,7 @@
   binom tbinom dbinom cfrac tfrac equal href
   sideset stackrel citeauthoryear
   setcounter addtocounter setlength addtolength
-  scalebox
+  scalebox texorpdfstring
   Call Function Procedure SetKw SetKwData SetKwFunction SetKwInOut)
 
 (logic-group latex-command-3%
@@ -95,7 +93,7 @@
   mathchoice)
 
 (logic-group latex-command-6%
-  @startsection)
+  genfrac @startsection)
 
 (logic-rules
   ((latex-command% 'x) (latex-command-0% 'x))
@@ -122,11 +120,12 @@
 (logic-group latex-command-1*%
   usepackage documentclass documentstyle sqrt bibitem cite caption  
   title author thanks
+  part chapter section subsection subsubsection paragraph subparagraph
   includegraphics includegraphics*
   subjclass declaretheorem footnotetext
   xleftarrow xrightarrow xleftrightarrow xminus
   xLeftarrow xRightarrow xLeftrightarrow xequal
-  xmapsto xmapsfrom
+  xmapsto xmapsfrom citealp citet citep citet* citep*
   Begin ELSIF FORALL FOR IF WHILE tcp tcp* tcc tcc*)
 
 (logic-group latex-command-2*%
@@ -165,7 +164,7 @@
   begin-tabbing begin-thebibliography begin-multicols)
 
 (logic-group latex-environment-1*%
-  begin-array begin-tabular)
+  begin-array begin-tabular begin-minipage)
 
 (logic-group latex-environment-2*%
   begin-tabular* begin-tabularx)
@@ -203,7 +202,7 @@
   textrm texttt textsf textmd textbf textup textit textsl textsc emph
   mathrm mathtt mathsf mathmd mathbf mathup mathit mathsl mathnormal
   mathcal mathfrak mathbb mathbbm mathscr operatorname boldsymbol
-  lowercase MakeLowercase uppercase MakeUppercase)
+  lowercase MakeLowercase uppercase MakeUppercase selectlanguage)
 
 (logic-rules
   ((latex-modifier% 'x) (latex-modifier-0% 'x))
@@ -383,12 +382,29 @@
 (logic-rules
   ((latex-arity% 'x 0) (latex-length% 'x)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; To be imported as pictures
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(logic-group latex-as-pic-0%
+  begin-pspicture begin-pspicture* begin-tikzpicture)
+
+(logic-group latex-as-pic-1%
+  xymatrix)
+
+(logic-rules
+  ((latex-as-pic% 'x)       (latex-as-pic-0% 'x))
+  ((latex-as-pic% 'x)       (latex-as-pic-1% 'x))
+  ((latex-arity%  'x 0)     (latex-as-pic-0% 'x))
+  ((latex-arity%  'x 1)     (latex-as-pic-1% 'x)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; To be ignored
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (logic-group latex-ignore-0%
   allowbreak notag xspace break sloppy makeatother makeatletter relax
+  qedhere
   ignorespacesafterend ignorespaces balancecolumns)
 
 (logic-group latex-ignore-0*%
@@ -428,6 +444,8 @@
 
 (logic-table latex-needs%
   (!verbatim "alltt")
+  (!verbatim* "alltt")
+  ("alltt" "alltt")
 
   (geometry "geometry")
   (epsfig "epsfig")
@@ -456,8 +474,8 @@
   (pod "amsmath")
   (overset "amsmath")
   (underset "amsmath")
-  (tmop "amsmath")
-  (tmmathbf "amsmath")
+  (operatorname "amsmath")
+  (boldsymbol "amsmath")
   (lleq "amsmath")
   (llleq "amsmath")
   (ggeq "amsmath")
@@ -475,6 +493,8 @@
   (xRightarrow "amsmath")
   (xLeftrightarrow "amsmath")
 
+  (proof "amsmath")
+
   (bigbox "stmaryrd")
   (bigcurlyvee "stmaryrd")
   (bigcurlywedge "stmaryrd")
@@ -489,13 +509,11 @@
   (mho "graphicx")
   (upequal "graphicx")
 
-  (tmfloat "ifthen")
-  (tmfloat "capt-of")
-  (tmfloat "calc")
+  (ifthenelse "ifthen")
+  (captionof "capt-of")
+  (widthof "calc")
   
-  (color "color")
-  (tmhlink "color")
-  (tmaction "color")
+  (color "xcolor")
 
   (omicron "pslatex")
   (multicols "multicol")
@@ -553,6 +571,7 @@
           ((logic-in? s latex-command%) "command")
           ((logic-in? s latex-length%) "length")
           ((logic-in? s latex-ignore%) "ignore")
+          ((logic-in? s latex-as-pic%) "as-picture")
           ((logic-in? s latex-name%) "name")
           ((logic-in? s latex-counter%) "counter")
 	  ((logic-in? s latex-modifier%) "modifier")
