@@ -18,7 +18,8 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (set-font-rules
-  `(((math $ecrm $cmr $cmmi $cmsy $msam $msbm $stmary $wasy $line
+  `(;; Main math font
+    ((math $ecrm $cmr $cmmi $cmsy $msam $msbm $stmary $wasy $line
 	   $cal $frak $bbb $upgreek $bold1 $bold2 $boldcal $cmex $s $d)
      (math
       (math (tex $cmr $s $d)
@@ -60,6 +61,7 @@
      (math $ecrm $cmr $cmmi cmbrsy cmbram cmbrbm stmary wasy line
 	   cmbrsy eufb bbmbx grxn cmbx cmmib cmbsy cmex $s $d))
 
+    ;; Upright math font
     ((var-math $ecrm $cmr $cmmi $cmsy $msam $msbm $stmary $wasy $line
 	       $cal $frak $bbb $upgreek $bold1 $bold2 $boldcal $cmex $s $d)
      (math
@@ -89,6 +91,50 @@
       (ec $ecrm $s $d)
       (ec ecrm $s $d)))
 
+    ;; Math font with modified italic math letters
+    ((alt-math $ecrm $ecti $cmr $cmmi $cmsy $msam $msbm $stmary $wasy $line
+               $cal $frak $bbb $upgreek $bold1 $bold2 $boldcal $cmex $s $d)
+     (math
+      (alt-math (tex $cmr $s $d)
+                (tex $cmmi $s $d)
+                (tex $ecti $s $d)
+                (tex $cmsy $s $d)
+                (tex $msam $s $d)
+                (tex $msbm $s $d)
+                (tex $stmary $s $d)
+                (tex $wasy $s $d)
+                (tex $line $s $d)
+                (tex $cmex $s $d)
+                (tex $cal $s $d)
+                (tex $frak $s $d)
+                (tex $bbb $s $d)
+                (tex $upgreek $s $d)
+                (tex $bold1 $s $d)
+                (tex $bold2 $s $d)
+                (tex $boldcal $s $d)
+                (virtual long $s $d)
+                (virtual negate $s $d)
+                (virtual misc $s $d))
+      (rubber (tex-rubber rubber-cmex $cmex $s $d)
+	      (tex-rubber rubber-stmary $stmary $s $d)
+	      (tex-rubber rubber-wasy $wasy $s $d)
+	      (tex-dummy-rubber (tex-rubber rubber-cmex $cmex $s $d)))
+      (ec $ecrm $s $d)
+      (ec ecrm $s $d)))
+
+    ((math-std $ecrm $cmr $cmmi $s $d)
+     (math $ecrm $cmr $cmmi cmsy msam msbm stmary wasy line
+	   cmsy eufm bbm grmn cmbx cmmib cmbsy cmex $s $d))
+    ((bold-math-std $ecrm $cmr $cmmi $s $d)
+     (math $ecrm $cmr $cmmi cmbsy msam msbm stmaryb wasyb linew
+	   cmbsy eufb bbmbx grxn cmbx cmmib cmbsy cmex $s $d))
+    ((math-conc $ecrm $cmr $cmmi $s $d)
+     (math $ecrm $cmr $cmmi xccsy xccam xccbm stmary wasy line
+	   cmsy eufm bbm grmn cmbx cmmib cmbsy xccex $s $d))
+    ((math-bright $ecrm $cmr $cmmi $s $d)
+     (math $ecrm $cmr $cmmi cmbrsy cmbram cmbrbm stmary wasy line
+	   cmbrsy eufb bbmbx grxn cmbx cmmib cmbsy cmex $s $d))
+
     ((math-var $ecrm $cmr $cmmi $s $d)
      (var-math $ecrm $cmr $cmmi cmsy msam msbm stmary wasy line
 	       cmsy eufm bbm grmn cmbx cmmib cmbsy cmex $s $d))
@@ -102,6 +148,19 @@
      (var-math $ecrm $cmr $cmmi cmbrsy cmbram cmbrbm stmary wasy line
 	       cmbrsy eufm bbm grmn cmbx cmmib cmbsy cmex $s $d))
 
+    ((math-alt $ecrm $ecti $cmr $cmmi $s $d)
+     (alt-math $ecrm $ecti $cmr $cmmi cmsy msam msbm stmary wasy line
+               cmsy eufm bbm grmn cmbx cmmib cmbsy cmex $s $d))
+    ((bold-math-alt $ecrm $ecti $cmr $cmmi $s $d)
+     (alt-math $ecrm $ecti $cmr $cmmi cmbsy msam msbm stmaryb wasyb linew
+               cmbsy eufb bbmbx grxn cmbx cmmib cmbsy cmex $s $d))
+    ((math-conc-alt $ecrm $ecti $cmr $cmmi $s $d)
+     (alt-math $ecrm $ecti $cmr $cmmi xccsy xccam xccbm stmary wasy line
+               cmsy eufm bbm grmn cmbx cmmib cmbsy xccex $s $d))
+    ((math-bright-alt $ecrm $ecti $cmr $cmmi $s $d)
+     (alt-math $ecrm $ecti $cmr $cmmi cmbrsy cmbram cmbrbm stmary wasy line
+               cmbrsy eufb bbmbx grxn cmbx cmmib cmbsy cmex $s $d))
+
     ((roman mr medium right $s $d) (math-var ecrm cmr cmmi $s $d))
     ((roman mr bold right $s $d) (bold-math-var ecbx cmbx cmmib $s $d))
     ((roman ms medium right $s $d) (math-var ecss cmss cmmi $s $d))
@@ -110,9 +169,9 @@
     ((roman mr medium $a $s $d) (math-std ecrm cmr cmmi $s $d))
     ((roman mr bold $a $s $d) (bold-math-std ecbx cmbx cmmib $s $d))
     ((roman ms light $a $s $d) (math-bright cmbr cmbr cmbrmi $s $d))
-    ((roman ms medium $a $s $d) (math-std ecss cmss cmssi $s $d))
-    ((roman ms bold $a $s $d) (math-std ecsx cmssbx cmmib $s $d))
-    ((roman mt medium $a $s $d) (math-std ectt cmtt cmitt $s $d))
+    ((roman ms medium $a $s $d) (math-alt ecss ecsi cmss cmmi $s $d))
+    ((roman ms bold $a $s $d) (math-alt ecsx ecso cmssbx cmmib $s $d))
+    ((roman mt medium $a $s $d) (math-alt ectt ecst cmtt cmitt $s $d))
 
     ((roman trm medium $a $s $d) (math-var ecrm cmr cmmi $s $d))
     ((roman trm bold $a $s $d) (bold-math-var ecbx cmbx cmmib $s $d))
@@ -132,9 +191,9 @@
     ((concrete mt medium right $s $d) (math-std ectt cmtt cmitt $s $d))
     ((concrete mr medium $a $s $d) (math-conc-var eorm ccr xcmmi $s $d))
     ((concrete mr bold $a $s $d) (math-conc-var ecbx cmbx cmmib $s $d))
-    ((concrete ms medium $a $s $d) (math-var ecss cmss cmmi $s $d))
-    ((concrete ms bold $a $s $d) (math-var ecsx cmssbx cmmib $s $d))
-    ((concrete mt medium $a $s $d) (math-var ectt cmtt cmmi $s $d))
+    ((concrete ms medium $a $s $d) (math-alt ecss ecsi cmss cmmi $s $d))
+    ((concrete ms bold $a $s $d) (math-alt ecsx ecso cmssbx cmmib $s $d))
+    ((concrete mt medium $a $s $d) (math-alt ectt ecst cmtt cmmi $s $d))
 
     ((concrete trm medium $a $s $d) (math-conc-var eorm ccr xcmmi $s $d))
     ((concrete trm bold $a $s $d) (math-conc-var ecbx cmbx cmmib $s $d))
