@@ -135,12 +135,14 @@
       ("Mathemagix" (make 'mmx))
       ("Scheme" (make 'scm))
       ("Shell" (make 'shell))
+      ("Scilab" (make 'scilab))
       ("Verbatim" (make 'verbatim)))
   (-> "Block of code"
       ("C++" (make 'cpp-code))
       ("Mathemagix" (make 'mmx-code))
       ("Scheme" (make 'scm-code))
       ("Shell" (make 'shell-code))
+      ("Scilab" (make 'scilab-code))
       ("Verbatim" (make 'verbatim-code))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -480,8 +482,11 @@
   #f)
 
 (tm-menu (focus-abstract-menu)
-  ("Keywords" (make-abstract-data-element 'abstract-keywords))
-  ("M.S.C." (make-abstract-data-element 'abstract-msc)))
+  ("Arxiv Category"               (make-abstract-data-element 'abstract-arxiv))
+  ("A.C.M. Computing Class."      (make-abstract-data-element 'abstract-acm))
+  ("A.M.S. Subject Class."        (make-abstract-data-element 'abstract-msc))
+  ("Physics and Astronomy Class." (make-abstract-data-element 'abstract-pacs))
+  ("Keywords"                 (make-abstract-data-element 'abstract-keywords)))
 
 (tm-define (focus-tag-name l)
   (:require (== l 'abstract))
